.. :changelog:

History
-------

1.3.0 (2016-12-12)
++++++++++++++++++

* WorkflowClient now supports count open or closed workflows by filter. Filter includes start time, close time, workflow type, tag, workflow id and close status.

1.1.0 (2016-10-03)
++++++++++++++++++

* Update botocore version to 1.4.46

1.0.0 (2016-09-09)
++++++++++++++++++

* Initial release of py_swf
